Zombie Nom Nom
===

This is a game engine that is modeled after the popular board game zombie dice. This is meant for practice to be able to be messed with and explored.

[![Test and Deploy Docs](https://github.com/Carrera-Dev-Consulting/zombie_nomnom/actions/workflows/deploy-docs.yaml/badge.svg)](https://github.com/Carrera-Dev-Consulting/zombie_nomnom/actions/workflows/deploy-docs.yaml)

Useful Links
---

Links to result of code coverage and pytest of latest builds.

* [Coverage Report](https://consulting.gxldcptrick.dev/zombie_nomnom/coverage/)
* [Latest Test Run](https://consulting.gxldcptrick.dev/zombie_nomnom/coverage/report.html)
* [Documentation](https://consulting.gxldcptrick.dev/zombie_nomnom/)

Installation
---

`pip install zombie_nomnom`


We require at least python 3.10 to be able to run properly.


Usage
---

# TODO(Dean): Fill in with details on how to use the die.

Contribution
---
# TODO(Milo): Add details to how to contribute to the repo
